/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfproperties.font;

import android.content.Context;
import android.graphics.Typeface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;

import androidx.annotation.NonNull;
import androidx.appcompat.widget.AppCompatTextView;

import com.compdfkit.core.annotation.CPDFTextAttribute;
import com.compdfkit.core.font.CPDFFont;
import com.compdfkit.core.font.CPDFFontName;
import com.compdfkit.tools.R;

import java.util.ArrayList;
import java.util.List;


public class CFontSpinnerAdapter1 extends BaseAdapter {

    private List<CPDFTextAttribute.FontNameHelper.FontType> list;

    private List<CPDFFontName> outFontList;

    private Context mContext;

    public CFontSpinnerAdapter1(@NonNull Context context) {
        ArrayList<CPDFTextAttribute.FontNameHelper.FontType> tempList = new ArrayList<>();
        tempList.add(CPDFTextAttribute.FontNameHelper.FontType.Helvetica);
        tempList.add(CPDFTextAttribute.FontNameHelper.FontType.Courier);
        tempList.add(CPDFTextAttribute.FontNameHelper.FontType.Times_Roman);
        list = tempList;
        outFontList= CPDFFont.getOutFontName();
        mContext = context;
    }

    @Override
    public int getCount() {
        return list.size() + (outFontList == null ? 0 : outFontList.size());
    }

    @Override
    public Object getItem(int position) {
        if (position < list.size()) {
            return list.get(position);
        } else {
            if (outFontList != null) {
                return outFontList.get(position - list.size());
            }
            return null;
        }
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        LayoutInflater inflater = LayoutInflater.from(mContext);
        convertView = inflater.inflate(R.layout.tools_spinner_list_item, null);
        if (convertView != null){
            AppCompatTextView textView = convertView.findViewById(R.id.tv_menu_title);
            if (position < list.size()){
                CPDFTextAttribute.FontNameHelper.FontType fontType = (CPDFTextAttribute.FontNameHelper.FontType) getItem(position);
                String fontName = CPDFTextAttribute.FontNameHelper.obtainFontName(fontType, false, false);
                Typeface typeface = CPDFTextAttribute.FontNameHelper.getInnerTypeface(textView.getContext(), fontName);
                if (fontType == CPDFTextAttribute.FontNameHelper.FontType.Unknown){
                    textView.setTypeface(Typeface.DEFAULT);
                    textView.setText(CPDFTextAttribute.FontNameHelper.FontType.Unknown.name());
                } else {
                    textView.setTypeface(typeface);
                    textView.setText(fontName);
                }
            }else {
                CPDFFontName outFontName = (CPDFFontName) getItem(position);
                String outFont = CPDFTextAttribute.FontNameHelper.obtainOutFontName(outFontName.getFamilyName(), false,false);
                Typeface typeface = CPDFTextAttribute.FontNameHelper.getTypeface(mContext, outFont);
                textView.setTypeface(typeface);
                textView.setText(outFontName.getFamilyName());
            }
        }
        return convertView;
    }

    public int getPosition(String fontName){
        for (int i = 0; i < list.size(); i++) {
            CPDFTextAttribute.FontNameHelper.FontType fontType = list.get(i);
            if (fontType.name().equals(fontName)){
                return i;
            }
        }
        for (int i = 0; i < outFontList.size(); i++) {
            CPDFFontName name = outFontList.get(i);
            if (name.getFamilyName().equals(fontName)) {
                return list.size() + i;
            }
        }
        return 0;
    }

    public CPDFFontName getCPDFFontName(String familyName){
        for (CPDFFontName cpdfFontName : outFontList) {
            if (cpdfFontName.getFamilyName().equals(familyName)) {
                return cpdfFontName;
            }
        }
        return null;
    }
}
