package com.compdfkit.tools.common.views.pdfproperties.font;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;

import androidx.annotation.NonNull;
import androidx.appcompat.widget.AppCompatTextView;

import com.compdfkit.core.annotation.CPDFTextAttribute;
import com.compdfkit.core.font.CPDFFontName;
import com.compdfkit.tools.R;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2024/2/26
 * description:
 */
public class CFontStyleSpinnerAdapter extends BaseAdapter {

    enum FontStyle {
        Normal,

        Bold,

        Italic,

        Bold_Italic
    }

    private List<FontStyle> list;

    private Context mContext;

    public CFontStyleSpinnerAdapter(@NonNull Context context) {
        list = new ArrayList<>();
        mContext = context;
    }

    @Override
    public int getCount() {
        return list.size();
    }

    @Override
    public FontStyle getItem(int position) {
        return list.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        LayoutInflater inflater = LayoutInflater.from(mContext);
        convertView = inflater.inflate(R.layout.tools_spinner_list_item, null);
        if (convertView != null) {
            AppCompatTextView textView = convertView.findViewById(R.id.tv_menu_title);
            switch (list.get(position)){
                case Normal:
                    textView.setText(R.string.tools_font_style_normal);
                    break;
                case Bold:
                    textView.setText(R.string.tools_font_style_bold);

                    break;
                case Italic:
                    textView.setText(R.string.tools_font_style_italic);

                    break;
                case Bold_Italic:
                    textView.setText(R.string.tools_font_style_bold_italic);
                    break;
            }

        }
        return convertView;
    }

    public void updateFontStyle(CPDFTextAttribute.FontNameHelper.FontType fontType){
        list.clear();
        list.addAll(Arrays.asList(FontStyle.values()));
        notifyDataSetChanged();
    }

    public void updateFontStyle(CPDFFontName outFamilyName){
       list.clear();
       list.add(FontStyle.Normal);
       if (outFamilyName.isSupportBold()){
           list.add(FontStyle.Bold);
       }

       if (outFamilyName.isSupportItalic()){
           list.add(FontStyle.Italic);
       }
       if (outFamilyName.isSupportBold() && outFamilyName.isSupportItalic()){
           list.add(FontStyle.Bold_Italic);
       }
       notifyDataSetChanged();
    }

    public int getIndex(boolean isBold, boolean isItalic){
        FontStyle style = FontStyle.Normal;
        if (isBold){
            style = FontStyle.Bold;
        }
        if (isItalic){
            if (isBold){
                style = FontStyle.Bold_Italic;
            }else {
                style = FontStyle.Italic;
            }
        }

        for (int i = 0; i < list.size(); i++) {
            FontStyle item = list.get(i);
            if (item == style){
                return i;
            }
        }
        return 0;
    }


}