/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfproperties.pdfstyle.manager.provider;


import android.text.TextUtils;

import com.compdfkit.core.annotation.CPDFTextAttribute;
import com.compdfkit.core.font.CPDFFont;
import com.compdfkit.tools.common.utils.CLog;
import com.compdfkit.tools.common.views.pdfproperties.pdfstyle.CAnnotStyle;
import com.compdfkit.tools.common.views.pdfproperties.pdfstyle.CStyleType;

import java.util.LinkedHashSet;

public interface CStyleProvider {

    public void updateStyle(CAnnotStyle annotStyle);

    public void updateStyle(LinkedHashSet<CAnnotStyle> annotStyle);

    public CAnnotStyle getStyle(CStyleType type);


    default public String getAnnotStyleFontName(CAnnotStyle annotStyle){
        String fontName;
        if (!TextUtils.isEmpty(annotStyle.getExternFontName())){
            fontName = CPDFTextAttribute.FontNameHelper.obtainOutFontName(annotStyle.getExternFontName(), annotStyle.isFontBold(), annotStyle.isFontItalic());
        } else {
            fontName = CPDFTextAttribute.FontNameHelper.obtainFontName(annotStyle.getFontType(), annotStyle.isFontBold(), annotStyle.isFontItalic());
        }
        CLog.e("字体", "更新字体：" + fontName);

        return fontName;
    }

    default public void updateAnnotStyleFont(CAnnotStyle annotStyle, String attrFontName){
        String familyName = CPDFFont.getFamilyName(attrFontName);
        CLog.e("字体", "获取到字体：" + attrFontName);
        if (!TextUtils.isEmpty(familyName)){
            annotStyle.setFontType(CPDFTextAttribute.FontNameHelper.FontType.Unknown);
            annotStyle.setExternFontName(familyName);
        }else {
            annotStyle.setFontType(CPDFTextAttribute.FontNameHelper.getFontType(attrFontName));
            annotStyle.setExternFontName("");
        }
    }
}
